* ENTERING DATA.
* read in an excel (.xls) file.
get data 
 /type=xls
 /file = 'c:\spss_data\hs0.xls'
 /sheet=name 'hs0'
 /readnames=on.

* read in a text file.
get data  
 /type = txt
 /file = 'c:\spss_data\hs0.csv'
 /delimiters = ","
 /firstcase = 2
 /variables =
  gender f.10
  id f3.0
  race f1.0
  ses f1.0
  schtype f1.0
  prog a8
  read f2.0
  write f2.0
  math f2.0
  science f2.0
  socst f2.0.
execute.

* read in a filed format ascii file.
data list fixed file "c:\spss_data\schdat.fix"
 / id 1-2 a1 3-4 t1 5-6 gender 7 a2 8-9 t2 10-11 tgender 12.
list
 /cases = from 1 to 10.

* input data directly using the syntax editor.
data list list
 /id female race ses * schtype (a3) prog read write math science socst.
begin data.
 147 1 1 3 pub 1 47  62  53  53  61
 108 0 1 2 pub 2 34  33  41  36  36
  18 0 3 2 pub 3 50  33  49  44  36
 153 0 1 2 pub 3 39  31  40  39  51
  50 0 2 2 pub 2 50  59  42  53  61
  51 1 2 1 pub 2 42  36  42  31  39
 102 0 1 1 pub 1 52  41  51  53  56
  57 1 1 2 pub 1 71  65  72  66  56
 160 1 1 2 pub 1 55  65  55  50  61
 136 0 1 2 pub 1 65  59  70  63  51
end data.

* open a SPSS data file.
get file 'c:\spss_data\hs0.sav'.

*EXPLORING DATA.
* opening the data file.
get file "c:\spss_data\hs0.sav".
* descriptives for some of the variables.
descriptives
  variables=gender read write math science.

* create a filter for reading scores 60 and above and.
* recomputing the descriptive statistics.
compute f_read60=(read >=  60).
filter by f_read60.
execute.

descriptives
  variables=gender read write math science.

* after removing the previous filter (with the "use all" command), create .
* a new filter and recompute the descriptive statistics.
use all.

compute f_acad=(prgtype="academic").
filter by f_acad.
execute.

descriptives
  variables=gender read write math science.

* after removing the previous filter, select the first 40 cases.
filter off.

use 1 thru 40.
execute.

descriptives
  variables=gender read write math science.

* compare means using all cases.
use all.

means tables = read write math science by prgtype.

* stem and leaf plot.
examine variables = write
 /plot stemleaf.

* boxplot.
examine variables = write by gender
 /plot = boxplot
 /statistics = none.

* histogram.
graph
 /histogram(normal) = write.

* histogram.
frequencies variables = ses
 /histogram.

frequencies variables = write
 /histogram.

* crosstabs.
crosstabs
 /tables = prgtype by ses.

* correlations.
correlations
 /variables=read write math science.

* changing from casewise to listwise deletion of missing data.
correlations
 /variables=read write math science
 /missing=listwise.

* scatterplot.
graph
 /scatterplot = read with write.

* SPSS does not provide code for including sun flowers on the graph.

* scatterplot matrix.
graph
 /scatterplot(matrix) = read write math science.


* MODIFYING DATA.
* open the data file.
get file "c:\spss_data\hs0.sav".

* ordering the variables in a way that makes sense.
save outfile = "c:\spss_data\hs01.sav" 
 / keep id gender all.
get file "c:\spss_data\hs01.sav".
display variables.

* adding variable and value labels to schtyp.
variable labels schtyp "the type of school the student attended.".
value labels schtyp 1 "public" 2 "private".
display dictionary 
 /var = schtyp.
list schtyp 
 /cases from 1 to 10.

* changing prgtype from a string to a numeric variable (called prog).  
autorecode variables = prgtype
/into prog
/print.

variable labels prog "the type of program in which the student was enrolled.".

rename variables (gender = female).
variable labels female "The gender of the student.".
value labels female 1 "female" 0 "male".
display dictionary
/variables = female.
list female 
/cases from 1 to 10.

* recoding race = 5 to missing.
frequencies var = race.
recode race (5 = sysmis).
frequencies var = race.

* adding notes to the data set and viewing the notes.
document the variable gender was renamed to female.
document  values of race coded as 5 were recoded to be missing.
display document.
drop document.

* creating a variable that is a total of some of the
* test scores.
compute total = read + write + math.

summarize var = total.

* creating a variable that is a total of the reading
* writing and social studies test scores.
compute total = read + write + socst.
variable labels total "the total of the reading, writing and social studies scores.".

* creating a variable that is a total of some of the test scores.
summarize var = total.
display dictionary
 /var = total.

* assigning some letter grades to these test scores.
recode total (0 thru 80=0) (80 thru 110 =1) (110 thru 140=2)
(140 thru 170=3) (170 thru 300=4) into grade.
execute.
value labels grade 0 "f" 1 "d" 2 "c" 3 "b" 4 "a".
variable labels grade "these are the combined grades of reading, writing and social studies scores.".
display dictionary
 /var = grade.
list read write socst grade 
 /cases from 1 to 10.

file label "High School and Beyond".

document The variable gender was renamed to female;
The values of race coded as 5 were recoded to be missing.
display document. 

* there is another way to create variables
* in SPSS that uses special functions.
descriptives var = read 
 /save.
summarize var = zread.
list read zread 
 /cases from 1 to 10.

aggregate
/break = ses
/rmean = mean(read).

save outfile "c:\spss_data\hs1.sav".

* MANAGING DATA.
* working on honors thesis.
* want to make a subset just keeping those who have read >= 60.
get file "c:\spss_data\hs1.sav".

* keeping cases for which students have a reading score of 60 or higher.
select if read >=60.
descriptives 
 /var=read.
save outfile "c:\spss_data\hsgoodread.sav".

* pretend we have 2000 variables and we want to keep just some of the variables.
* we want to keep just the variables id female read write.
save outfile = "c:\spss_data\hskept.sav" 
 /keep=id  female read write.
display names.
get file "c:\spss_data\hskept.sav".
display names.

* extra example not in point and click.
* we want to drop just the variables ses and prog.
get file "c:\spss_data\hsgoodread.sav".
save outfile "c:\spss_data\hsdropped.sav" 
 /drop=ses prog.
display names.
get file "c:\spss_data\hsdropped.sav".
display names.

* have one file with males, females in another file and need to "append" the files.
get file "c:\spss_data\hsmale.sav".
freq 
 /var=female.

add files 
 /file=* 
 /file="c:\spss_data\hsfemale.sav".
freq 
 /var=female.

save outfile "c:\spss_data\hsmasters.sav".

* one file has demographic scores, the other has test scores and we want to "match merge" the files.
get file "c:\spss_data\hsdem.sav".
list cases from 1 to 10.

sort cases by id.
save outfile "c:\spss_data\hsdem.sav".

get file "c:\spss_data\hstest.sav".
list cases from 1 to 10.

sort cases by id.
save outfile "c:\spss_data\hstest.sav".

get file "c:\spss_data\hsdem.sav".
match files 
 /file=* 
 /in=fromdem 
 /file="c:\spss_data\hstest.sav" 
 /in=fromtest
 /by id.

list cases from 1 to 10.

list variables id fromdem fromtest.
crosstab 
 /tables=fromdem by fromtest.

save outfile "c:\spss_data\hsdiss.sav".

* ANALYZING DATA.
get file "c:\spss_data\hs1.sav".

* chi-square test.
crosstabs
  /tables prgtype by ses
  /statistic = chisq.
* t-tests.
t-test
  /testval=50
  /variables=write.

t-test
  groups=female(0 1)
  /variables=write.

t-test
  pairs= write with science (paired).

* anova.
glm
  write  by prog
  /design = prog.

glm
  write  by prog ses
  /design = prog, ses, prog*ses
  /plot = profile(prog*ses).

glm
  write  by prog ses
  /design = prog, ses, prog*ses
  /posthoc = prog(tukey).
  
* ancova.
glm
 math with science write
 /design= science write.

* regression.
regression
  /dependent math
  /method=enter write science.

regression
  /dependent math
  /method=enter socst write ses
  /scatterplot=(*zresid ,*zpred ).

* creating an outlier, running the regression and looking at the outlier.
if id=1 write=100.
exe.

regression
  /dependent math
  /method=enter socst write ses
  /scatterplot=(*zresid ,*zpred ).

* removing the outlier.
if id=1 write=44.
exe.

regression
  /dependent math
  /method=enter socst write ses
  /save resid.

*residual plots.
pplot
  /variables=res_1
  /type=p-p
  /dist=normal.

pplot
  /variables=res_1
  /type=q-q
  /dist=normal.

* creating a dichotomous variable.
compute honcomp = (write > 60).
execute.

* logistic regression.
logistic regression var=honcomp
  /method=enter read socst.

* non-parametric tests.

* binomial test.
npar test
  /binomial (.50)= write (50).

* sign test.
npar test
  /sign= read with write (paired).

*signrank test.
npar tests
  /m-w= write by female(1 0).

* kruskal-wallis test.
npar tests
  /k-w=write by prog(1 3).


